/* 
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 * 
 * http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 *
 */

package org.apache.muse.tools.generator.synthesizer;

import org.apache.muse.tools.generator.util.ConfigurationData;
import org.apache.muse.tools.generator.util.ConfigurationDataDescriptor;
import org.apache.muse.tools.generator.util.SubscriptionManagerHelper;

/**
 * A <code>Synthesizer</code> implementation that creates
 * the server-side stubs for a set of capabilities. This involves creating
 * accessors and constants for any properties and creating the operation 
 * templates that are to be filled-in by implementors. Unlike
 * <code>ProxyGenerator</code> the code that comes out of this
 * phase will throw Exceptions when any method is invoked because by
 * default the methods have no implementation and simply throw
 * 
 * <code>new RuntimeException("Unimplemented Method");");</code>
 *
 * @author Andrew Eberbach (aeberbac)
 * 
 * @see org.apache.muse.tools.generator.synthesizer.Synthesizer
 */
public class ServerSynthesizer implements Synthesizer {
	
	static ConfigurationDataDescriptor[] REQUIRED_PARAMETERS = 
		new ConfigurationDataDescriptor[] {
			ConfigurationData.CAPABILITIES_MAP_LIST_CONFIGURATION,
		};

	public ConfigurationData synthesize(ConfigurationData data) throws Exception {        
        ServerInterfaceSynthesizer serverInterfaceSynthesizer = new ServerInterfaceSynthesizer();
        ServerClassSynthesizer serverClassSynthesizer = new ServerClassSynthesizer();
        
        data = serverInterfaceSynthesizer.synthesize(data);
        data = serverClassSynthesizer.synthesize(data);
        
        data = SubscriptionManagerHelper.addSubscriptionManager(data);
        
        return data;
	}
	
	public ConfigurationDataDescriptor[] getConfigurationDataDescriptions() {
		return REQUIRED_PARAMETERS;
	}
}
