/* 
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 * 
 * http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 *
 */

package org.apache.muse.tools.generator.util;

import java.util.Collection;
import java.util.HashSet;

import javax.wsdl.extensions.schema.Schema;

import org.apache.muse.tools.inspector.JavaMethod;
import org.apache.muse.tools.inspector.JavaProperty;

/**
 * This is a container class for data gathered from analyzing
 * a WSDL. It contains information about operations, properties and
 * their associated Capability URI.
 * 
 * @author Andrew Eberbach (aeberbac)
 */
public class Capability {

	private boolean _builtIn = false;
	
	private Collection _operations = new HashSet();

	private Collection _properties = new HashSet();

	private Schema _schema;

	private String _uri;

	private String _className;

	public Capability(String uri) {
		_uri = uri;
	}

	public String getURI() {
		return _uri;
	}

	public Schema getSchema() {
		return _schema;
	}

	public void addProperty(JavaProperty property) {
		_properties.add(property);
	}

	public void addOperation(JavaMethod method) {
		_operations.add(method);
	}

	public Collection getOperations() {
		return _operations;
	}

	public Collection getProperties() {
		return _properties;
	}
	
	public void setImplementingClass(String className) {
		_className = className;
	}
	
	public String getImplementingClass() {
		return _className;
	}
	
	public boolean isBuiltIn() {
		return _builtIn;
	}
	
	public void setBuiltIn(boolean builtIn) {
		_builtIn = builtIn;
	}

	public boolean isEmpty() {
		return (_operations.size() + _properties.size()) == 0;
	}
}
