/* 
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 * 
 * http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 *
 */

package org.apache.muse.tools.generator.util;

import java.io.PrintWriter;
import java.io.StringWriter;
import java.util.logging.Formatter;
import java.util.logging.Level;
import java.util.logging.LogRecord;
import java.util.logging.Logger;

import org.apache.muse.util.messages.Messages;
import org.apache.muse.util.messages.MessagesFactory;

/**
 * @author Andrew Eberbach (aeberbac)
 *
 */
public class SimpleLogFormatter extends Formatter {	
	private Messages _MESSAGES = MessagesFactory.get(SimpleLogFormatter.class);

	private Logger _logger = Logger.getLogger(AbstractCommandLineApp.TOP_LEVEL_PACKAGE);
	
	public String format(LogRecord record) {
		StringBuffer result = new StringBuffer("\n");
		
		if(!record.getLevel().equals(Level.INFO)) {
			result.append(record.getLevel().getName() + ": ");
		}

		result.append(record.getMessage());
		
		Throwable thrown = record.getThrown();
		if(thrown != null) {
			result.append("\n\n" + _MESSAGES.get("ExceptionMessage",false));
			result.append(thrown.getMessage() + "\n\n");						

			if(_logger.getLevel().intValue() == Level.ALL.intValue()) {
				result.append(_MESSAGES.get("StackTrace",false) + "\n\n");
				
				StringWriter sw = new StringWriter();
				PrintWriter pw = new PrintWriter(sw);
				thrown.printStackTrace(pw);
				result.append(sw.getBuffer().toString());
			}
		}
					
		result.append("\n");
		
		return result.toString();
	}
}
