/* 
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 * 
 * http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 *
 */

package org.apache.muse.tools.generator.util;

import java.io.File;
import java.io.InputStream;
import java.net.URI;
import java.net.URL;
import java.net.URLConnection;

import org.apache.muse.util.messages.Messages;
import org.apache.muse.util.messages.MessagesFactory;

public class WsdlEnvironment extends LocalEnvironment {

	private Messages _MESSAGES = MessagesFactory.get(WsdlEnvironment.class);
	
    private static final String HTTP_SCHEME = "http";

	public WsdlEnvironment(File wsdl) {
		super(wsdl);
	}

	public InputStream getDataResourceStream(String path) 
    {
    	URI uri = URI.create(path);		
		String scheme = uri.getScheme();
		
		if(scheme != null && uri.getScheme().equals(HTTP_SCHEME)) {
			try {
				URLConnection conn = new URL(path).openConnection();
				return conn.getInputStream();
			} catch (Exception e) {				
				Object[] filler = { path, e.getMessage() };
				throw new MuseRuntimeException("FailedRemoteFile", _MESSAGES.get("FailedRemoteFile", filler), e);
			}
		}
        return super.getDataResourceStream(path);
    }
}
